==> coser-web-1.0.2-sources.jar: fr/ifremer/coser/web/actions/common/CommonIndicator.java <==
/*
 * #%L
 * $Id: CommonIndicator.java 668 2011-02-04 10:47:43Z chatellier $
 * $HeadURL: svn+ssh://chatellier@labs.libre-entreprise.org/svnroot/coser/tags/coser-1.0.2/coser-web/src/main/java/fr/ifremer/coser/web/actions/common/CommonIndicator.java $
 * %%
 * Copyright (C) 2010 - 2011 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package fr.ifremer.coser.web.actions.common;

import java.util.Locale;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import fr.ifremer.coser.CoserBusinessException;
import fr.ifremer.coser.services.WebService;
import fr.ifremer.coser.web.CoserWebException;
import fr.ifremer.coser.web.ServiceFactory;

/**
 * Recupere la liste des indicateurs à partir d'une zone et d'une espece (peut
 * être null dans le cas des communautés).
 * 
 * @author chatellier
 * @version $Revision: 668 $
 * 
 * Last update : $Date: 2011-02-04 11:47:43 +0100 (ven., 04 févr. 2011) $
 * By : $Author: chatellier $
 */
public abstract class CommonIndicator extends CoserAction {

    /** serialVersionUID. */
    private static final long serialVersionUID = 1663244944108703571L;

    private static final Log log = LogFactory.getLog(CommonIndicator.class);

    protected String facade;

    protected String zone;

    protected String species;
    
    protected String zonePicture;

    protected Map<String, String> indicators;

    public String getFacade() {
        return facade;
    }

    public void setFacade(String facade) {
        this.facade = facade;
    }

    public String getZone() {
        return zone;
    }

    public void setZone(String zone) {
        this.zone = zone;
    }

    public String getSpecies() {
        return species;
    }

    public void setSpecies(String species) {
        this.species = species;
    }

    public Map<String, String> getIndicators() {
        return indicators;
    }
    
    public String getZonePicture() {
        return zonePicture;
    }

    public String getFacadeDisplayName() {
        WebService webService = ServiceFactory.getWebService();
        String displayName = null;
        try {
            displayName = webService.getFacades().get(facade);
        } catch (CoserBusinessException ex) {
            throw new CoserWebException("Can't get facade display name", ex);
        }
        return displayName;
    }
    
    public String getZoneDisplayName() {
        WebService webService = ServiceFactory.getWebService();
        String displayName = null;
        try {
            displayName = webService.getZoneForFacade(facade, false).get(zone);
        } catch (CoserBusinessException ex) {
            throw new CoserWebException("Can't get zone display name", ex);
        }
        return displayName;
    }
    
    public String getSpeciesDisplayName() {
        WebService webService = ServiceFactory.getWebService();
        String displayName = null;
        try {
            displayName = webService.getSpecies(zone).get(species);
        } catch (CoserBusinessException ex) {
            throw new CoserWebException("Can't get species display name", ex);
        }
        return displayName;
    }

    @Override
    public String execute() {

        if (log.isInfoEnabled()) {
            log.info(String.format("Looking for indicator for zone %s and species %s", zone, species));
        }

        WebService webService = ServiceFactory.getWebService();

        Locale locale = getLocale();
        String localeCode = locale.getLanguage();

        try {
            indicators = webService.getIndicators(zone, species, localeCode);
            
            zonePicture = webService.getZonePictures().get(zone);
        } catch (CoserBusinessException ex) {
            throw new CoserWebException("Can't get indicators", ex);
        }

        return SUCCESS;
    }
}

==> coser-web-1.0.3-sources.jar: fr/ifremer/coser/web/actions/common/CommonIndicator.java <==
/*
 * #%L
 * $Id: CommonIndicator.java 797 2011-03-24 15:45:33Z chatellier $
 * $HeadURL: svn+ssh://chatellier@labs.libre-entreprise.org/svnroot/coser/tags/coser-1.0.3/coser-web/src/main/java/fr/ifremer/coser/web/actions/common/CommonIndicator.java $
 * %%
 * Copyright (C) 2010 - 2011 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package fr.ifremer.coser.web.actions.common;

import java.util.Locale;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import fr.ifremer.coser.CoserBusinessException;
import fr.ifremer.coser.services.WebService;
import fr.ifremer.coser.web.CoserWebException;
import fr.ifremer.coser.web.ServiceFactory;

/**
 * Recupere la liste des indicateurs à partir d'une zone et d'une espece (peut
 * être null dans le cas des communautés).
 * 
 * @author chatellier
 * @version $Revision: 797 $
 * 
 * Last update : $Date: 2011-03-24 16:45:33 +0100 (jeu., 24 mars 2011) $
 * By : $Author: chatellier $
 */
public abstract class CommonIndicator extends CoserAction {

    /** serialVersionUID. */
    private static final long serialVersionUID = 1663244944108703571L;

    private static final Log log = LogFactory.getLog(CommonIndicator.class);

    protected String facade;

    protected String zone;

    protected String species;
    
    protected String zonePicture;

    protected Map<String, String> indicators;

    public String getFacade() {
        return facade;
    }

    public void setFacade(String facade) {
        this.facade = facade;
    }

    public String getZone() {
        return zone;
    }

    public void setZone(String zone) {
        this.zone = zone;
    }

    public String getSpecies() {
        return species;
    }

    public void setSpecies(String species) {
        this.species = species;
    }

    public Map<String, String> getIndicators() {
        return indicators;
    }
    
    public String getZonePicture() {
        return zonePicture;
    }

    public String getFacadeDisplayName() {
        WebService webService = ServiceFactory.getWebService();
        String displayName = null;
        try {
            displayName = webService.getFacades().get(facade);
        } catch (CoserBusinessException ex) {
            throw new CoserWebException("Can't get facade display name", ex);
        }
        return displayName;
    }
    
    public String getZoneDisplayName() {
        WebService webService = ServiceFactory.getWebService();
        String displayName = null;
        try {
            displayName = webService.getZoneForFacade(facade, false, false).get(zone);
        } catch (CoserBusinessException ex) {
            throw new CoserWebException("Can't get zone display name", ex);
        }
        return displayName;
    }
    
    public String getSpeciesDisplayName() {
        WebService webService = ServiceFactory.getWebService();
        String displayName = null;
        try {
            displayName = webService.getSpecies(zone, false).get(species);
        } catch (CoserBusinessException ex) {
            throw new CoserWebException("Can't get species display name", ex);
        }
        return displayName;
    }

    @Override
    public String execute() {

        if (log.isInfoEnabled()) {
            log.info(String.format("Looking for indicator for zone %s and species %s", zone, species));
        }

        WebService webService = ServiceFactory.getWebService();

        Locale locale = getLocale();
        String localeCode = locale.getLanguage();

        try {
            indicators = webService.getIndicators(zone, species, localeCode);
            
            zonePicture = webService.getZonePictures().get(zone);
        } catch (CoserBusinessException ex) {
            throw new CoserWebException("Can't get indicators", ex);
        }

        return SUCCESS;
    }
}
